# Dijit Tree V1 API Test

This file is for testing the old Tree API's, where the store is specified directly rather than specifying a model which connects to a store.

### Tree with hardcoded root node (not corresponding to any item in the store)

Clicking a folder node will open/close it (openOnclick==true), and clicking a leaf node will change the display name of the leaf node.

## A rootless tree (no "continents" node) with custom icons